@@ -4,14 +4,14 @@ use super::*;
 pub struct Class(pub TypeDef);
 
 impl Class {
-    pub fn interfaces(&self) -> Vec<InterfaceInfo> {
+    fn interfaces(&self) -> Vec<InterfaceInfo> {
         fn add_interfaces(result: &mut Vec<InterfaceInfo>, parent: &TypeDef, is_base: bool) {
             for child in parent.interface_impls() {
                 if let ElementType::TypeDef(def) = child.generic_interface(&parent.generics) {
                     let kind = if !is_base && child.is_default() {
                         InterfaceKind::Default
                     } else if child.is_overridable() {
-                        InterfaceKind::Overridable
+                        continue;
                     } else {
                         InterfaceKind::NonDefault
                     };
@@ -79,6 +79,7 @@ impl Class {
         let interfaces = self.interfaces();
         let features = gen.class_features(&self.0);
         let cfg = gen.gen_cfg(&features);
+        let doc = gen.gen_cfg_doc(&features);
 
         if include == TypeInclude::Full {
             let methods = InterfaceInfo::gen_methods(&interfaces, gen);
@@ -110,8 +111,8 @@ impl Class {
                 let guid = gen_type_guid(&default_interface.def, gen);
                 let default_abi_name = gen_abi_name(&default_interface.def, gen);
                 let type_signature = Literal::byte_string(self.0.type_signature().as_bytes());
-                let object = gen_object(&name, &TokenStream::new(), &cfg);
-                let (async_get, future) = gen_async(&self.0, &interfaces, gen);
+                let inspectable = gen_inspectable(&name, &TokenStream::new(), &cfg);
+                let (async_get, future) = gen_async(&self.0, &interfaces, gen, &cfg);
 
                 let new = if self.0.has_default_constructor() {
                     quote! {
@@ -148,9 +149,10 @@ impl Class {
 
                 quote! {
                     #cfg
+                    #doc
                     #[repr(transparent)]
                     #[derive(::std::cmp::PartialEq, ::std::cmp::Eq, ::std::clone::Clone, ::std::fmt::Debug)]
-                    pub struct #name(::windows::runtime::IInspectable);
+                    pub struct #name(pub ::windows::runtime::IInspectable);
                     #cfg
                     impl #name {
                         #new
@@ -172,7 +174,7 @@ impl Class {
                         const NAME: &'static str = #runtime_name;
                     }
                     #future
-                    #object
+                    #inspectable
                     #(#conversions)*
                     #(#bases)*
                     #send_sync
@@ -180,6 +182,7 @@ impl Class {
                 }
             } else {
                 quote! {
+                    #doc
                     pub struct #name {}
                     impl #name {
                         #methods
@@ -201,7 +204,7 @@ impl Class {
                 #[repr(transparent)]
                 #[derive(::std::cmp::PartialEq, ::std::cmp::Eq, ::std::clone::Clone, ::std::fmt::Debug)]
                 #[doc(hidden)]
-                pub struct #name(::windows::runtime::IInspectable);
+                pub struct #name(pub ::windows::runtime::IInspectable);
                 #cfg
                 unsafe impl ::windows::runtime::Interface for #name {
                     type Vtable = <::windows::runtime::IUnknown as ::windows::runtime::Interface>::Vtable;
@@ -261,8 +264,6 @@ impl Class {
             }
         })
     }
-
-    // TODO: don't generate conversions for exclusive interfaces
 }
 
 #[cfg(test)]
