@@ -108,14 +108,19 @@ pub fn gen_enum(def: &TypeDef, gen: &Gen, include: TypeInclude) -> TokenStream {
             unsafe impl ::windows::runtime::RuntimeType for #name {
                 const SIGNATURE: ::windows::runtime::ConstBuffer = ::windows::runtime::ConstBuffer::from_slice(#signature);
             }
+            impl ::windows::runtime::DefaultType for #name {
+                type DefaultType = Self;
+            }
         }
     } else {
         quote! {}
     };
 
     let extensions = gen_extensions(def);
+    let doc = gen.gen_cfg_doc(&BTreeSet::new());
 
     quote! {
+        #doc
         #[derive(::std::cmp::PartialEq, ::std::cmp::Eq, ::std::marker::Copy, ::std::clone::Clone, ::std::default::Default, ::std::fmt::Debug)]
         #[repr(transparent)]
         pub struct #name(pub #underlying_type);
@@ -127,7 +132,6 @@ pub fn gen_enum(def: &TypeDef, gen: &Gen, include: TypeInclude) -> TokenStream {
         }
         unsafe impl ::windows::runtime::Abi for #name {
             type Abi = Self;
-            type DefaultType = Self;
         }
         #runtime_type
         #bitwise
