@@ -26,13 +26,7 @@ pub fn gen_function(def: &MethodDef, gen: &Gen) -> TokenStream {
         }
     };
 
-    let arch = if let Some(arch) = def.supported_arch() {
-        quote! { #[cfg(target_arch = #arch)] }
-    } else {
-        quote! {}
-    };
-
-    let features = method_features(&signature, gen);
+    let cfg = gen.gen_function_cfg(def.attributes(), &signature);
 
     match signature.kind() {
         SignatureKind::Query => {
@@ -41,8 +35,7 @@ pub fn gen_function(def: &MethodDef, gen: &Gen) -> TokenStream {
             let params = gen_win32_params(leading_params, gen);
 
             quote! {
-                #arch
-                #features
+                #cfg
                 #[inline]
                 pub unsafe fn #name<#constraints T: ::windows::runtime::Interface>(#params) -> ::windows::runtime::Result<T> {
                     #[cfg(windows)]
@@ -65,8 +58,7 @@ pub fn gen_function(def: &MethodDef, gen: &Gen) -> TokenStream {
             let params = gen_win32_params(leading_params, gen);
 
             quote! {
-                #arch
-                #features
+                #cfg
                 #[inline]
                 pub unsafe fn #name<#constraints T: ::windows::runtime::Interface>(#params result__: *mut ::std::option::Option<T>) -> ::windows::runtime::Result<()> {
                     #[cfg(windows)]
@@ -89,8 +81,7 @@ pub fn gen_function(def: &MethodDef, gen: &Gen) -> TokenStream {
             let return_type_tokens = gen_win32_result_type(&signature, gen);
 
             quote! {
-                #arch
-                #features
+                #cfg
                 #[inline]
                 pub unsafe fn #name<#constraints>(#params) -> ::windows::runtime::Result<#return_type_tokens> {
                     #[cfg(windows)]
@@ -112,8 +103,7 @@ pub fn gen_function(def: &MethodDef, gen: &Gen) -> TokenStream {
             let args = signature.params.iter().map(gen_win32_abi_arg);
 
             quote! {
-                #arch
-                #features
+                #cfg
                 #[inline]
                 pub unsafe fn #name<#constraints>(#params) -> ::windows::runtime::Result<()> {
                     #[cfg(windows)]
@@ -134,8 +124,7 @@ pub fn gen_function(def: &MethodDef, gen: &Gen) -> TokenStream {
             let args = signature.params.iter().map(gen_win32_abi_arg);
 
             quote! {
-                #arch
-                #features
+                #cfg
                 #[inline]
                 pub unsafe fn #name<#constraints>(#params) #abi_return_type {
                     #[cfg(windows)]
