@@ -2,7 +2,7 @@
 
 use super::*;
 
-pub fn gen_guid(guid: &Guid) -> TokenStream {
+pub fn gen_guid(guid: &GUID) -> TokenStream {
     let a = Literal::u32_unsuffixed(guid.0);
     let b = Literal::u16_unsuffixed(guid.1);
     let c = Literal::u16_unsuffixed(guid.2);
@@ -22,17 +22,17 @@ pub fn gen_guid(guid: &Guid) -> TokenStream {
 
 pub fn gen_type_guid(def: &TypeDef, gen: &Gen) -> TokenStream {
     if def.generics.is_empty() {
-        match Guid::from_attributes(def.attributes()) {
+        match GUID::from_attributes(def.attributes()) {
             Some(guid) => {
                 let guid = gen_guid(&guid);
 
                 quote! {
-                    ::windows::Guid::from_values(#guid)
+                    ::windows::runtime::GUID::from_values(#guid)
                 }
             }
             None => {
                 quote! {
-                    ::windows::Guid::zeroed()
+                    ::windows::runtime::GUID::zeroed()
                 }
             }
         }
@@ -40,7 +40,7 @@ pub fn gen_type_guid(def: &TypeDef, gen: &Gen) -> TokenStream {
         let tokens = gen_type_name(def, gen);
 
         quote! {
-            ::windows::Guid::from_signature(<#tokens as ::windows::RuntimeType>::SIGNATURE)
+            ::windows::runtime::GUID::from_signature(<#tokens as ::windows::runtime::RuntimeType>::SIGNATURE)
         }
     }
 }
@@ -49,11 +49,11 @@ pub fn gen_guid_signature(def: &TypeDef, signature: &str) -> TokenStream {
     let signature = Literal::byte_string(signature.as_bytes());
 
     if def.generics.is_empty() {
-        return quote! { ::windows::ConstBuffer::from_slice(#signature) };
+        return quote! { ::windows::runtime::ConstBuffer::from_slice(#signature) };
     }
 
     let generics = def.generics.iter().enumerate().map(|(index, g)| {
-        let g = gen_name(g, &Gen::Absolute);
+        let g = gen_name(g, &Gen::absolute());
         let semi = if index != def.generics.len() - 1 {
             Some(quote! {
                 .push_slice(b";")
@@ -63,14 +63,14 @@ pub fn gen_guid_signature(def: &TypeDef, signature: &str) -> TokenStream {
         };
 
         quote! {
-            .push_other(<#g as ::windows::RuntimeType>::SIGNATURE)
+            .push_other(<#g as ::windows::runtime::RuntimeType>::SIGNATURE)
             #semi
         }
     });
 
     quote! {
         {
-            ::windows::ConstBuffer::new()
+            ::windows::runtime::ConstBuffer::new()
             .push_slice(b"pinterface(")
             .push_slice(#signature)
             .push_slice(b";")
