@@ -32,6 +32,7 @@ mod vector2;
 mod vector3;
 mod vector4;
 mod win32;
+mod win32_error;
 mod winrt;
 
 // TODO: These public things are mostly/all used by the implement macro
@@ -74,3 +75,4 @@ use timespan::*;
 use vector2::*;
 use vector3::*;
 use vector4::*;
+use win32_error::*;
