@@ -1,31 +1,57 @@
 use super::*;
 
-pub fn gen_object(name: &TokenStream, constraints: &TokenStream, features: &TokenStream) -> TokenStream {
+pub fn gen_unknown(name: &TokenStream) -> TokenStream {
+    quote! {
+        impl ::std::convert::From<#name> for ::windows::runtime::IUnknown {
+            fn from(value: #name) -> Self {
+                value.0
+            }
+        }
+        impl ::std::convert::From<&#name> for ::windows::runtime::IUnknown {
+            fn from(value: &#name) -> Self {
+                value.0.clone()
+            }
+        }
+        impl<'a> ::windows::runtime::IntoParam<'a, ::windows::runtime::IUnknown> for #name {
+            fn into_param(self) -> ::windows::runtime::Param<'a, ::windows::runtime::IUnknown> {
+                ::windows::runtime::Param::Owned(self.0)
+            }
+        }
+        impl<'a> ::windows::runtime::IntoParam<'a, ::windows::runtime::IUnknown> for &'a #name {
+            fn into_param(self) -> ::windows::runtime::Param<'a, ::windows::runtime::IUnknown> {
+                ::windows::runtime::Param::Borrowed(&self.0)
+            }
+        }
+    }
+}
+
+pub fn gen_inspectable(name: &TokenStream, constraints: &TokenStream, features: &TokenStream) -> TokenStream {
     quote! {
         #features
         impl<#constraints> ::std::convert::From<#name> for ::windows::runtime::IUnknown {
             fn from(value: #name) -> Self {
-                unsafe { ::std::mem::transmute(value) }
+                value.0.0
             }
         }
         #features
         impl<#constraints> ::std::convert::From<&#name> for ::windows::runtime::IUnknown {
             fn from(value: &#name) -> Self {
-                ::std::convert::From::from(::std::clone::Clone::clone(value))
+                value.0.0.clone()
             }
         }
         #features
         impl<'a, #constraints> ::windows::runtime::IntoParam<'a, ::windows::runtime::IUnknown> for #name {
             fn into_param(self) -> ::windows::runtime::Param<'a, ::windows::runtime::IUnknown> {
-                ::windows::runtime::Param::Owned(::std::convert::Into::<::windows::runtime::IUnknown>::into(self))
+                ::windows::runtime::Param::Owned(self.0.0)
             }
         }
         #features
-        impl<'a, #constraints> ::windows::runtime::IntoParam<'a, ::windows::runtime::IUnknown> for &#name {
+        impl<'a, #constraints> ::windows::runtime::IntoParam<'a, ::windows::runtime::IUnknown> for &'a #name {
             fn into_param(self) -> ::windows::runtime::Param<'a, ::windows::runtime::IUnknown> {
-                ::windows::runtime::Param::Owned(::std::convert::Into::<::windows::runtime::IUnknown>::into(::std::clone::Clone::clone(self)))
+                ::windows::runtime::Param::Borrowed(&self.0.0)
             }
         }
+
         #features
         impl<#constraints> ::std::convert::From<#name> for ::windows::runtime::IInspectable {
             fn from(value: #name) -> Self {
