@@ -8,10 +8,10 @@ use super::*;
 // TODO: api contracts are being generated
 
 pub fn gen_struct(def: &TypeDef, gen: &Gen) -> TokenStream {
-    gen_struct_with_name(def, def.name(), gen)
+    gen_struct_with_name(def, def.name(), gen, &TokenStream::new())
 }
 
-fn gen_struct_with_name(def: &TypeDef, struct_name: &str, gen: &Gen) -> TokenStream {
+fn gen_struct_with_name(def: &TypeDef, struct_name: &str, gen: &Gen, cfg: &TokenStream) -> TokenStream {
     if let Some(replacement) = gen_replacement(def) {
         return replacement;
     }
@@ -50,13 +50,19 @@ fn gen_struct_with_name(def: &TypeDef, struct_name: &str, gen: &Gen) -> TokenStr
             unsafe impl ::windows::runtime::Handle for #name {}
             unsafe impl ::windows::runtime::Abi for #name {
                 type Abi = Self;
-                type DefaultType = Self;
             }
             #convertible
         };
     }
 
-    let features = struct_features(def, gen);
+    let (doc, cfg) = if cfg.is_empty() {
+        let features = features(def, gen);
+        let cfg = gen.gen_struct_cfg(def, &features);
+        let doc = gen.gen_cfg_doc(&features);
+        (doc, cfg)
+    } else {
+        (TokenStream::new(), cfg.clone())
+    };
 
     let fields: Vec<(Field, Signature, TokenStream)> = def
         .fields()
@@ -111,10 +117,14 @@ fn gen_struct_with_name(def: &TypeDef, struct_name: &str, gen: &Gen) -> TokenStr
         let signature = Literal::byte_string(def.type_signature().as_bytes());
 
         quote! {
-            #features
+            #cfg
             unsafe impl ::windows::runtime::RuntimeType for #name {
                 const SIGNATURE: ::windows::runtime::ConstBuffer = ::windows::runtime::ConstBuffer::from_slice(#signature);
             }
+            #cfg
+            impl ::windows::runtime::DefaultType for #name {
+                type DefaultType = Self;
+            }
         }
     } else {
         quote! {}
@@ -126,7 +136,7 @@ fn gen_struct_with_name(def: &TypeDef, struct_name: &str, gen: &Gen) -> TokenStr
         }
     } else if is_union || has_union || is_packed {
         quote! {
-            #features
+            #cfg
             impl ::std::clone::Clone for #name {
                 fn clone(&self) -> Self {
                     // TODO: this can transmute for blittable but not non-blittable structs
@@ -162,18 +172,16 @@ fn gen_struct_with_name(def: &TypeDef, struct_name: &str, gen: &Gen) -> TokenStr
 
     let abi = if def.is_blittable() {
         quote! {
-            #features
+            #cfg
             unsafe impl ::windows::runtime::Abi for #name {
                 type Abi = Self;
-                type DefaultType = Self;
             }
         }
     } else {
         quote! {
-            #features
+            #cfg
             unsafe impl ::windows::runtime::Abi for #name {
                 type Abi = ::std::mem::ManuallyDrop<Self>;
-                type DefaultType = Self;
             }
         }
     };
@@ -195,14 +203,14 @@ fn gen_struct_with_name(def: &TypeDef, struct_name: &str, gen: &Gen) -> TokenStr
 
     let compare = if is_union | has_union | has_complex_array | is_packed {
         quote! {
-            #features
+            #cfg
             impl ::std::cmp::PartialEq for #name {
                 fn eq(&self, _other: &Self) -> bool {
                     // TODO: figure out how to compare complex structs
                     unimplemented!()
                 }
             }
-            #features
+            #cfg
             impl ::std::cmp::Eq for #name {}
         }
     } else {
@@ -222,24 +230,24 @@ fn gen_struct_with_name(def: &TypeDef, struct_name: &str, gen: &Gen) -> TokenStr
 
         if layout.is_some() {
             quote! {
-                #features
+                #cfg
                 impl ::std::cmp::PartialEq for #name {
                     fn eq(&self, other: &Self) -> bool {
                         unsafe { #(#compare)&&* }
                     }
                 }
-                #features
+                #cfg
                 impl ::std::cmp::Eq for #name {}
             }
         } else {
             quote! {
-                #features
+                #cfg
                 impl ::std::cmp::PartialEq for #name {
                     fn eq(&self, other: &Self) -> bool {
                         #(#compare)&&*
                     }
                 }
-                #features
+                #cfg
                 impl ::std::cmp::Eq for #name {}
             }
         }
@@ -271,7 +279,7 @@ fn gen_struct_with_name(def: &TypeDef, struct_name: &str, gen: &Gen) -> TokenStr
 
         if layout.is_some() {
             quote! {
-                #features
+                #cfg
                 impl ::std::fmt::Debug for #name {
                     fn fmt(&self, fmt: &mut ::std::fmt::Formatter<'_>) -> ::std::fmt::Result {
                         unsafe {
@@ -284,7 +292,7 @@ fn gen_struct_with_name(def: &TypeDef, struct_name: &str, gen: &Gen) -> TokenStr
             }
         } else {
             quote! {
-                #features
+                #cfg
                 impl ::std::fmt::Debug for #name {
                     fn fmt(&self, fmt: &mut ::std::fmt::Formatter<'_>) -> ::std::fmt::Result {
                         fmt.debug_struct(#debug_name)
@@ -297,18 +305,19 @@ fn gen_struct_with_name(def: &TypeDef, struct_name: &str, gen: &Gen) -> TokenStr
     };
 
     let extensions = gen_extensions(def);
-    let nested_types = gen_nested_types(struct_name, def, gen);
+    let nested_types = gen_nested_types(struct_name, def, gen, &cfg);
 
     quote! {
         #clone_or_copy
         #repr
-        #features
+        #cfg
+        #doc
         pub #struct_or_union #name #body
-        #features
+        #cfg
         impl #name {
             #(#constants)*
         }
-        #features
+        #cfg
         impl ::std::default::Default for #name {
             fn default() -> Self {
                 unsafe { ::std::mem::zeroed() }
@@ -347,14 +356,14 @@ fn gen_extensions(def: &TypeDef) -> TokenStream {
     }
 }
 
-fn gen_nested_types<'a>(enclosing_name: &'a str, enclosing_type: &'a TypeDef, gen: &Gen) -> TokenStream {
+fn gen_nested_types<'a>(enclosing_name: &'a str, enclosing_type: &'a TypeDef, gen: &Gen, cfg: &TokenStream) -> TokenStream {
     if let Some(nested_types) = enclosing_type.nested_types() {
         nested_types
             .iter()
             .enumerate()
             .map(|(index, (_, nested_type))| {
                 let nested_name = format!("{}_{}", enclosing_name, index);
-                gen_struct_with_name(nested_type, &nested_name, gen)
+                gen_struct_with_name(nested_type, &nested_name, gen, cfg)
             })
             .collect()
     } else {
